==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/space/messages/cy/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Invite</strong> members' => '',
    '<strong>New</strong> member request' => '',
    '<strong>New</strong> spaces' => '',
    '<strong>Request</strong> Membership' => '',
    '<strong>Space</strong> followers' => '',
    '<strong>Space</strong> members' => '',
    '<strong>Space</strong> menu' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'About' => '',
    'Accept' => '',
    'Accept Invite' => '',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => '',
    'Add users without invitation' => '',
    'Admin' => '',
    'Administrator:' => '',
    'Administrators' => '',
    'Any' => '',
    'Archived' => '',
    'As owner you cannot revoke your membership!' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Cancel' => '',
    'Close' => '',
    'Color' => '',
    'Could not request membership!' => '',
    'Created At' => '',
    'Created By' => '',
    'Decline' => '',
    'Decline Invite' => '',
    'Default' => '',
    'Default content visibility' => '',
    'Delete' => '',
    'Description' => '',
    'Do you really want to delete your profile image?' => '',
    'Do you really want to delete your title image?' => '',
    'Done' => '',
    'Email addresses' => '',
    'Everyone can enter' => '',
    'Find Spaces by their description or by their tags' => '',
    'Follow' => '',
    'Followers' => '',
    'Following' => '',
    'Guests' => '',
    'Hide Members sidebar in the stream page.' => '',
    'Homepage' => '',
    'Homepage (Guests)' => '',
    'I want to become a member because...' => '',
    'Invite' => '',
    'Invite and request' => '',
    'Invite by email' => '',
    'Invites' => '',
    'Join' => '',
    'Join Policy' => '',
    'Last Visit' => '',
    'Login' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Member since' => '',
    'Members' => '',
    'Moderator' => '',
    'Moderator:' => '',
    'Moderators' => '',
    'My Space List' => '',
    'My space summary' => '',
    'Name' => '',
    'Neither..nor' => '',
    'New user by e-mail (comma separated)' => '',
    'New user?' => '',
    'Newest first' => '',
    'No results found!' => '',
    'No spaces found.' => '',
    'Oldest first' => '',
    'Only by invite' => '',
    'Originator User ID' => '',
    'Owner' => '',
    'Owner:' => '',
    'Pending' => '',
    'Pick users' => '',
    'Posts' => '',
    'Private' => '',
    'Private (Invisible)' => '',
    'Public' => '',
    'Public (Members & Guests)' => '',
    'Public (Members only)' => '',
    'Public (Registered users only)' => '',
    'Request Message' => '',
    'Role' => '',
    'Search...' => '',
    'See all' => '',
    'Select all registered users' => '',
    'Send' => '',
    'Settings' => '',
    'Settings could not be saved!' => '',
    'Show all' => '',
    'Shown on About Page.' => '',
    'Sorry, you are not allowed to leave this space!' => '',
    'Sorting' => '',
    'Space' => '',
    'Space Visibility' => '',
    'Space directory' => '',
    'Space is invisible!' => '',
    'Spaces' => '',
    'Status' => '',
    'Stream' => '',
    'Tags' => '',
    'There is no pending invite!' => '',
    'This action is only available for workspace members!' => '',
    'This user is already a member of this space.' => '',
    'This user is not a member of this space.' => '',
    'To invite users to this space, please type their names below to find and pick them.' => '',
    'Try other keywords or remove filters.' => '',
    'Updated At' => '',
    'Updated By' => '',
    'Updated by' => '',
    'User \'{username}\' is already a member of this space!' => '',
    'User invitations have been added to the queue' => '',
    'User memberships have been added to the queue' => '',
    'User not found!' => '',
    'Users' => '',
    'Users has been invited.' => '',
    'Visibility' => '',
    'Visible for all (members and guests)' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
    'You are not allowed to join this space!' => '',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => '',
    'You cannot create private visible spaces!' => '',
    'You cannot create public visible spaces!' => '',
    'You need to login to view contents of this space!' => '',
    'Your Message' => '',
    'Your request was successfully submitted to the space administrators.' => '',
    '{count} members' => '',
    '{email} is not valid!' => '',
];

==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/space/messages/cy/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Invite</strong> members' => '',
    '<strong>New</strong> member request' => '',
    '<strong>New</strong> spaces' => '',
    '<strong>Request</strong> Membership' => '',
    '<strong>Space</strong> followers' => '',
    '<strong>Space</strong> members' => '',
    '<strong>Space</strong> menu' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'About' => '',
    'Accept' => '',
    'Accept Invite' => '',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => '',
    'Add users without invitation' => '',
    'Admin' => '',
    'Administrator:' => '',
    'Administrators' => '',
    'Any' => '',
    'Archived' => '',
    'As owner you cannot revoke your membership!' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Cancel' => '',
    'Close' => '',
    'Color' => '',
    'Could not request membership!' => '',
    'Create new link' => '',
    'Created At' => '',
    'Created By' => '',
    'Decline' => '',
    'Decline Invite' => '',
    'Default' => '',
    'Default content visibility' => '',
    'Delete' => '',
    'Description' => '',
    'Do you really want to delete your profile image?' => '',
    'Do you really want to delete your title image?' => '',
    'Done' => '',
    'Email addresses' => '',
    'Everyone can enter' => '',
    'Find Spaces by their description or by their tags' => '',
    'Follow' => '',
    'Followers' => '',
    'Following' => '',
    'Guests' => '',
    'Hide About Page' => '',
    'Hide Activity Sidebar Widget' => '',
    'Hide Followers' => '',
    'Hide Members' => '',
    'Homepage' => '',
    'Homepage (Non-members)' => '',
    'I want to become a member because...' => '',
    'Invite' => '',
    'Invite and request' => '',
    'Invite by email' => '',
    'Invite by link' => '',
    'Invite link' => '',
    'Invites' => '',
    'Join' => '',
    'Join Policy' => '',
    'Last Visit' => '',
    'Login' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Member since' => '',
    'Members' => '',
    'Moderator' => '',
    'Moderator:' => '',
    'Moderators' => '',
    'My Space List' => '',
    'My space summary' => '',
    'Name' => '',
    'Neither..nor' => '',
    'New user by e-mail (comma separated)' => '',
    'New user?' => '',
    'Newest first' => '',
    'No results found!' => '',
    'No spaces found.' => '',
    'Oldest first' => '',
    'Only by invite' => '',
    'Originator User ID' => '',
    'Owner' => '',
    'Owner:' => '',
    'Pending' => '',
    'Pick users' => '',
    'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => '',
    'Posts' => '',
    'Private' => '',
    'Private (Invisible)' => '',
    'Public' => '',
    'Public (Members & Guests)' => '',
    'Public (Members only)' => '',
    'Public (Registered users only)' => '',
    'Request Message' => '',
    'Role' => '',
    'Search...' => '',
    'See all' => '',
    'Select all registered users' => '',
    'Send' => '',
    'Send the link via email' => '',
    'Settings' => '',
    'Settings could not be saved!' => '',
    'Show all' => '',
    'Show as List' => '',
    'Shown on About Page.' => '',
    'Sorry, you are not allowed to leave this space!' => '',
    'Sorting' => '',
    'Space' => '',
    'Space Visibility' => '',
    'Space directory' => '',
    'Space is invisible!' => '',
    'Spaces' => '',
    'Status' => '',
    'Stream' => '',
    'Tags' => '',
    'The default homepage for members of this Space' => '',
    'The default homepage for non-members and guests visiting this Space' => '',
    'The secure link has been copied in your clipboard!' => '',
    'There is no pending invite!' => '',
    'This action is only available for workspace members!' => '',
    'This user is already a member of this space.' => '',
    'This user is not a member of this space.' => '',
    'To invite users to this space, please type their names below to find and pick them.' => '',
    'Try other keywords or remove filters.' => '',
    'Updated At' => '',
    'Updated By' => '',
    'Updated by' => '',
    'User \'{username}\' is already a member of this space!' => '',
    'User invitations have been added to the queue' => '',
    'User memberships have been added to the queue' => '',
    'User not found!' => '',
    'Users' => '',
    'Users has been invited.' => '',
    'Visibility' => '',
    'Visible for all (members and guests)' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
    'You are not allowed to join this space!' => '',
    'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => '',
    'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => '',
    'You cannot create private visible spaces!' => '',
    'You cannot create public visible spaces!' => '',
    'You need to login to view contents of this space!' => '',
    'Your Message' => '',
    'Your request was successfully submitted to the space administrators.' => '',
    '{count} members' => '',
    '{email} is not valid!' => '',
];
